==> qmmp-plugin-pack-1.0.3.tar.bz2: qmmp-plugin-pack-1.0.3/src/Input/xmp/translations/xmp_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="52"/>
        <source>XMP Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="66"/>
        <source>Module Files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="121"/>
        <source>About XMP Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="122"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="123"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="124"/>
        <source>Compiled against libxmp-%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source> Amplification factor:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="49"/>
        <source>File name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Volume scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Number of patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Number of tracks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Tracks per pattern</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Number of instruments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="60"/>
        <source>Number of samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="61"/>
        <source>Initial speed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="62"/>
        <source>Initial BPM</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="63"/>
        <source>Module length in patterns</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="82"/>
        <source>Samples</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="90"/>
        <source>Instruments</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="95"/>
        <source>Comment</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp-plugin-pack-1.2.0.tar.bz2: qmmp-plugin-pack-1.2.0/src/Input/xmp/translations/xmp_plugin_pt_BR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pt_BR">
<context>
    <name>DecoderXmpFactory</name>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="41"/>
        <source>XMP Plugin</source>
        <translation>Plugin XMP</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="55"/>
        <source>Module Files</source>
        <translation>Arquivos MOD</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="110"/>
        <source>About XMP Audio Plugin</source>
        <translation>Sobre o plugin XMP Audio</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="111"/>
        <source>Qmmp XMP Audio Plugin</source>
        <translation>Plugin Qmmp XMP Audio</translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="112"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../decoderxmpfactory.cpp" line="113"/>
        <source>Compiled against libxmp-%1</source>
        <translation>Compilado com libxmp-%1</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>XMP Plugin Settings</source>
        <translation>Preferências do plugin XMP</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="34"/>
        <source> Amplification factor:</source>
        <translation>Fator de amplificação:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Stereo mixing:</source>
        <translation>Mixagem estéreo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source> Interpolation type:</source>
        <translation>Tipo de interpolação:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <source>Lowpass filter effect</source>
        <translation>Efeito lowpass</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Use vblank timing</source>
        <translation>Utilizar temporização vblank</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="92"/>
        <source>Emulate Protracker 2.x FX9 bug</source>
        <translation>Emular erro Protracker 2.x FX9</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="99"/>
        <source>Sample rate:</source>
        <translation>Frequência:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="33"/>
        <source>22050 Hz</source>
        <translation>22050 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="34"/>
        <source>44100 Hz</source>
        <translation>44100 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="35"/>
        <source>48000 Hz</source>
        <translation>48000 Hz</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="36"/>
        <source>Nearest neighbor</source>
        <translation>Vizinhança mais próxima</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="37"/>
        <source>Linear</source>
        <translation>Linear</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="38"/>
        <source>Cubic spline</source>
        <translation>Spline cúbica</translation>
    </message>
</context>
<context>
    <name>XmpMetaDataModel</name>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="49"/>
        <source>File name</source>
        <translation>Nome do arquivo</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="54"/>
        <source>Format</source>
        <translation>Formato</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="55"/>
        <source>Volume scale</source>
        <translation>Escala de volume</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="56"/>
        <source>Number of patterns</source>
        <translation>Número de padrões</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="57"/>
        <source>Number of tracks</source>
        <translation>Número de faixas</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="58"/>
        <source>Tracks per pattern</source>
        <translation>Faixas por padrão</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="59"/>
        <source>Number of instruments</source>
        <translation>Número de instrumentos</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="60"/>
        <source>Number of samples</source>
        <translation>Número de amostras</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="61"/>
        <source>Initial speed</source>
        <translation>Velocidade inicial</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="62"/>
        <source>Initial BPM</source>
        <translation>BPM inicial</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="63"/>
        <source>Module length in patterns</source>
        <translation>Tamanho do módulo em padrões</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="82"/>
        <source>Samples</source>
        <translation>Amostras</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="90"/>
        <source>Instruments</source>
        <translation>Instrumentos</translation>
    </message>
    <message>
        <location filename="../xmpmetadatamodel.cpp" line="95"/>
        <source>Comment</source>
        <translation>Comentário</translation>
    </message>
</context>
</TS>
